//
//  GBFileItem.h
//  gBrowser
//
//  Created by Andreas Schwarz on Thu Apr 18 2002.
//  Copyright (c) 2001 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <AASFilesystemTools/AASFilesystemTools.h>
#import "GBMarkableItemProtocol.h"
#import "GBTypes.h"





@interface GBFileItem : AASBasicInfoFileItem <GBMarkableItemProtocol> {
    /// More file info ///	    
    NSImage *fileIcon;
    NSImage *genericIcon;
    char hasCustomIcon;
    
    NSString *modificationDateString;
    NSDate *creationDate;
    NSString *creationDateString;
    NSString *fileSizeString;
    NSNumber * fileSize;
    	
    char isImage;
    char isText;
    char isMovie;
    char isMusic;
    char isInTrash;
    
	NSInteger imageOrientation;
        
	char imageMetadataEditable;
    
	NSDictionary *imageProperties;
	NSMutableDictionary *marks;

	NSNumber * orientation;
	NSString * EXIFDateString;
	NSNumber * dimensionsWidth;
	NSNumber * dimensionsHeight;
	NSNumber * megapixels;
	NSNumber * ISO;
	NSNumber * exposureTime;
	NSNumber * fNumber;
	NSNumber * generalOrientation;
	NSNumber * focalLength;
	NSValue * trueDimensions;
	NSValue * dimensions;
	NSString * dimensionsString;
	NSString * megapixelString;
	NSString * imageDepthString;
	NSString * ICCProfileString;
	NSString * ISOString;
	NSString * exposureTimeString;
	NSString * fNumberString;
	NSString * resolutionString;
	NSString * generalOrientationString;
	NSString * focalLengthString;
	NSString * cameraModelString;
	NSDate * EXIFDate;
}


#pragma mark -
#pragma mark File Information

@property(readonly) NSString * fileSizeString;
@property(readonly) NSNumber * fileSize;

@property(readonly) NSString * modificationDateString;
@property(readonly) NSString * creationDateString;
@property(readonly) NSDate * creationDate;

@property(readonly) BOOL isImage;
@property(readonly) BOOL isMovie;
@property(readonly) BOOL isText;
@property(readonly) BOOL isMusic;

@property(readonly) BOOL isMedia;

@property(readonly) BOOL isInTrash;

@property(readonly) GBFileItem *preferredApplication;
@property(readonly) GBFileItem *editorApplication;




#pragma mark -
#pragma mark Image Information

@property (readonly) BOOL hasEditableImageMetadata;

@property(readonly) NSDictionary * imageProperties;

@property(readonly) NSNumber * orientation;
@property(readonly) NSString * EXIFDateString;
@property(readonly) NSNumber * dimensionsWidth;
@property(readonly) NSNumber * megapixels;
@property(readonly) NSNumber * ISO;
@property(readonly) NSNumber * exposureTime;
@property(readonly) NSNumber * fNumber;
@property(readonly) NSNumber * generalOrientation;
@property(readonly) NSNumber * focalLength;
@property(readonly) NSValue * trueDimensions;
@property(readonly) NSValue * dimensions;
@property(readonly) NSString * dimensionsString;
@property(readonly) NSString * megapixelString;
@property(readonly) NSString * imageDepthString;
@property(readonly) NSString * ICCProfileString;
@property(readonly) NSString * ISOString;
@property(readonly) NSString * exposureTimeString;
@property(readonly) NSString * fNumberString;
@property(readonly) NSString * resolutionString;
@property(readonly) NSString * generalOrientationString;
@property(readonly) NSString * focalLengthString;
@property(readonly) NSString * cameraModelString;
@property(readonly) NSDate * EXIFDate;


#pragma mark -
#pragma mark Settable Properties


- (BOOL)setImageOrientation:(NSInteger)newOrientation;



#pragma mark -
#pragma mark Icons and Thumbnails

@property(readonly) NSImage * fileIcon;
@property(readonly) NSImage * genericIcon;

@property(readonly) BOOL hasCustomIcon;




#pragma mark -


- (BOOL)countOfFiles:(NSUInteger *)files folders:(NSUInteger *)folders total:(NSUInteger *)total fileFilter:(AASFileFilter *)fileFilter directoryFilter:(AASFileFilter *)directoryFilter;




#pragma mark -
#pragma mark Actions


- (BOOL)setAsDesktopPicture:(NSInteger)screenNumber;




#pragma mark -
#pragma mark Sorting

@property(readonly) id finderLabelSortValue;

- (NSComparisonResult)sortFilesByName:(id)otherItem;
- (NSComparisonResult)sortFilesByPath:(id)otherItem;
- (id)comparisonValueForType:(GBSortTypes)sortType;

CFComparisonResult GBFileSortByContext(const void *obj1, const void *obj2, void *context);
CFComparisonResult GBFileSort(id obj1, id obj2, NSUInteger type, NSUInteger reverseSort, NSUInteger folderSort);


#pragma mark -
#pragma mark Filter Class Methods

+ (NSNumber *)filterImages:(GBFileItem *)file;
+ (NSNumber *)filterNoFolders:(GBFileItem *)file;
+ (NSNumber *)filterSupportedTypes:(GBFileItem *)file;


@end








